Crate uv_extract

Crate uv_extract 

Modules

dirhash
Dirhash is a scheme for hashing directory trees, and by extension the contents of archive files.
hash
stream

Enums

Error

Functions

insecure_no_validate
Returns true if ZIP validation is disabled.
strip_component
Extract the top-level directory from an unpacked archive.
unzip
Unzip a .zip archive into the target directory.
unzip_and_hash
Unzip a .zip archive into the target directory while computing a hash tree of the extracted files.