DirhashTree

Struct DirhashTree 

pub struct DirhashTree { /* private fields */ }
An in-memory directory structure for computing a dirhash from an archive as we unpack it, when the entries might come out in any order.

See the module-level example for usage.

Implementations

Source

impl DirhashTree

pub fn new() -> Self

Create an new, empty DirhashTree.

pub fn add_file(&mut self, path: &str, hash: Hash) -> Result<(), DirhashError>

Add a pre-hashed file to the tree. It’s an error if the filepath already exists.

path is a Unix-style, /-separated relative path. This is the format used in ZIP archives. Trailing slashes are ignored.

This function creates parent directories as needed.

The hash of a file is the standard blake3::hash of its contents. If the file is already on disk, the typical way to hash it is either blake3::Hasher::update_reader (ordinary serial reads) or blake3::Hasher::update_mmap_rayon (memory mapping plus multithreading). However, note that if you’re also writing the file to disk, it’s more efficient to hash it as you write it than to read it back again. See blake3_copy.

pub fn update_file( &mut self, path: &str, hash: Hash, ) -> Result<(), DirhashError>

Update the hash of a file in the tree. It’s an error if the filepath doesn’t exist or if it refers to a directory.

path is a Unix-style, /-separated relative path. This is the format used in ZIP archives. Trailing slashes are ignored.

The separation between add_file and update_file is intended to catch cases where an archive has duplicate entries for the same filepath. Those cases should ideally produce an error during unpacking, rather than arbitrarily picking a winner. update_file is intended for callers who are deliberately changing the contents of a path that already exists.

pub fn add_empty_dir(&mut self, path: &str) -> Result<(), DirhashError>

Add an empty directory to the tree. This succeeds if the directory already exists, but it’s an error if the path refers to a file.

path is a Unix-style, /-separated relative path. This is the format used in ZIP archives. Trailing slashes are ignored.

This function creates parent directories as needed.

pub fn hash(&self) -> Hash

Compute the root dirhash of the assembled tree.

This method is idempotent, and you can call it again after adding more files or updating existing ones. However, DirhashTree doesn’t currently cache the subtree hashes of unchanged directories, so calling hash repeatedly can be wasteful.