Modules
- dirhash
- Dirhash is a scheme for hashing directory trees, and by extension the contents of archive files.
- hash
- stream
Enums
Functions
- insecure_
no_ validate - Returns
trueif ZIP validation is disabled. - strip_
component - Extract the top-level directory from an unpacked archive.
- unzip
- Unzip a
.ziparchive into the target directory. - unzip_
and_ hash - Unzip a
.ziparchive into the target directory while computing a hash tree of the extracted files.